@@ -252,8 +252,8 @@ class Blaster():
                 trim = len(nucl_sequence) % 3
                 if trim != 0:
                     nucl_sequence = nucl_sequence + Seq('N' * (3 - trim))
-                prot_sequence = nucl_sequence.translate(
-                    table=11, to_stop=True)
+                prot_sequence = nucl_sequence.replace('-', 'N').translate(
+                    table=11, to_stop=True, gap='-')
 
                 id = str(hit_data['SEQUENCE'] +
                          '_' + hit_data['GENE']) + str('_' + hit_data['ACCESSION'])
